==> bobril-css-bootstrap-0.0.3.tgz: package/src/formField.js <==
"use strict";
var b = require('bobril');
var fg = require('./formGroup');
var i = require('./input');
var s = require('./select');
function input(label, value, onChange, help) {
    if (help === void 0) { help = undefined; }
    return fg.default({
        content: [
            { tag: 'label', children: label },
            i.default({ value: value, onChange: onChange, placeHolder: label }),
        ],
        help: help
    });
}
exports.input = input;
function date(label, value, onChange, help) {
    if (help === void 0) { help = undefined; }
    return fg.default({
        content: [
            { tag: 'label', children: label },
            i.default({ value: value, onChange: onChange, placeHolder: label, type: i.Type.Date }),
        ],
        help: help
    });
}
exports.date = date;
function time(label, value, onChange, help) {
    if (help === void 0) { help = undefined; }
    return fg.default({
        content: [
            { tag: 'label', children: label },
            i.default({ value: value, onChange: onChange, placeHolder: label, type: i.Type.Time }),
        ],
        help: help
    });
}
exports.time = time;
function dateTime(label, value, onChange, help) {
    if (help === void 0) { help = undefined; }
    return fg.default({
        content: [
            { tag: 'label', children: label },
            i.default({ value: value, onChange: onChange, placeHolder: label, type: i.Type.DateTime }),
        ],
        help: help
    });
}
exports.dateTime = dateTime;
function numeric(label, value, onChange, validatiors, help) {
    if (validatiors === void 0) { validatiors = []; }
    if (help === void 0) { help = undefined; }
    validatiors = [{
        validate: function (value) {
            var numeric = parseFloat(value);
            return numeric || numeric === 0 ? true : false;
        }
    }].concat(validatiors);
    return b.createComponent({
        render: function (ctx, me) {
            me.children = fg.default({
                content: [
                    { tag: 'label', children: ctx.data.label },
                    i.default({
                        value: ctx.data.value,
                        onChange: function (value) {
                            if (isValueInvalid(ctx.data.validatiors, value))
                                b.invalidate(ctx);
                            else
                                ctx.data.onChange(parseFloat(value));
                        },
                        placeHolder: ctx.data.label
                    }),
                ],
                help: help,
                validationState: isValueInvalid(ctx.data.validatiors, ctx.data.value.toString()) && fg.ValidationState.Error
            });
        }
    })({ label: label, value: value, onChange: onChange, validatiors: validatiors });
}
exports.numeric = numeric;
function isValueInvalid(validatiors, value) {
    return validatiors.filter(function (v) { return !v.validate(value); }).length > 0;
}
function password(label, value, onChange, error, shouldHaveFocus, help) {
    if (shouldHaveFocus === void 0) { shouldHaveFocus = false; }
    if (help === void 0) { help = undefined; }
    return fg.default({
        content: [
            { tag: 'label', children: label },
            i.default({ value: value, onChange: onChange, placeHolder: label, type: i.Type.Password, shouldHaveFocus: shouldHaveFocus }),
        ],
        help: help,
        validationState: error && fg.ValidationState.Error
    });
}
exports.password = password;
function select(label, items, selectedItemKey, onChange, isDisabled, help) {
    if (isDisabled === void 0) { isDisabled = false; }
    if (help === void 0) { help = undefined; }
    return fg.default({
        content: [
            { tag: 'label', children: label },
            s.default({ items: items, selectedItem: selectedItemKey, isDisabled: isDisabled, onChange: onChange })
        ],
        help: help
    });
}
exports.select = select;
function readOnly(label, value, help) {
    if (help === void 0) { help = undefined; }
    return fg.default({
        content: [
            { tag: 'label', className: 'control-label', children: label },
            { tag: 'div', children: { tag: 'p', className: 'form-control-static', children: value } }
        ],
        help: help
    });
}
exports.readOnly = readOnly;

==> bobril-css-bootstrap-0.0.5.tgz: package/src/formField.js <==
import * as b from 'bobril';
import * as fg from './formGroup';
import * as i from './input';
import * as s from './select';
export function input(label, value, onChange, help = undefined) {
    return fg.default({
        content: [
            { tag: 'label', children: label },
            i.default({ value: value, onChange: onChange, placeHolder: label }),
        ],
        help: help
    });
}
export function date(label, value, onChange, help = undefined) {
    return fg.default({
        content: [
            { tag: 'label', children: label },
            i.default({ value: value, onChange: onChange, placeHolder: label, type: i.Type.Date }),
        ],
        help: help
    });
}
export function time(label, value, onChange, help = undefined) {
    return fg.default({
        content: [
            { tag: 'label', children: label },
            i.default({ value: value, onChange: onChange, placeHolder: label, type: i.Type.Time }),
        ],
        help: help
    });
}
export function dateTime(label, value, onChange, help = undefined) {
    return fg.default({
        content: [
            { tag: 'label', children: label },
            i.default({ value: value, onChange: onChange, placeHolder: label, type: i.Type.DateTime }),
        ],
        help: help
    });
}
export function numeric(label, value, onChange, validatiors = [], help = undefined) {
    validatiors = [{
            validate: (value) => {
                let numeric = parseFloat(value);
                return numeric || numeric === 0 ? true : false;
            }
        }, ...validatiors];
    return b.createComponent({
        render(ctx, me) {
            me.children = fg.default({
                content: [
                    { tag: 'label', children: ctx.data.label },
                    i.default({
                        value: ctx.data.value,
                        onChange: (value) => {
                            if (isValueInvalid(ctx.data.validatiors, value))
                                b.invalidate(ctx);
                            else
                                ctx.data.onChange(parseFloat(value));
                        },
                        placeHolder: ctx.data.label
                    }),
                ],
                help: help,
                validationState: isValueInvalid(ctx.data.validatiors, ctx.data.value.toString()) && fg.ValidationState.Error
            });
        }
    })({ label: label, value: value, onChange: onChange, validatiors: validatiors });
}
function isValueInvalid(validatiors, value) {
    return validatiors.filter(v => !v.validate(value)).length > 0;
}
export function password(label, value, onChange, error, shouldHaveFocus = false, help = undefined) {
    return fg.default({
        content: [
            { tag: 'label', children: label },
            i.default({ value: value, onChange: onChange, placeHolder: label, type: i.Type.Password, shouldHaveFocus: shouldHaveFocus }),
        ],
        help: help,
        validationState: error && fg.ValidationState.Error
    });
}
export function select(label, items, selectedItemKey, onChange, isDisabled = false, help = undefined) {
    return fg.default({
        content: [
            { tag: 'label', children: label },
            s.default({ items: items, selectedItem: selectedItemKey, isDisabled: isDisabled, onChange: onChange })
        ],
        help: help
    });
}
export function readOnly(label, value, help = undefined) {
    return fg.default({
        content: [
            { tag: 'label', className: 'control-label', children: label },
            { tag: 'div', children: { tag: 'p', className: 'form-control-static', children: value } }
        ],
        help: help
    });
}
